pub enum RegisterStorageEnum {
Vmo(MappedVmoRegs),
Heap(HeapRegs),
}Expand description
An enum to hold the registers in either a heap or a vmo.
This is introduced to allow CurrentTask to store registers in heap during initialization and
link to the vmo after the RestrictedState is created.
Variants