RestrictedState

Struct RestrictedState 

pub struct RestrictedState {
    pub bound_state: NonNull<zx_restricted_state_t>,
    /* private fields */
}
RestrictedState manages accesses into the restricted state VMO.

See zx_restricted_bind_state.

Fields

bound_state: NonNull<zx_restricted_state_t>

Implementations

Source

impl RestrictedState

pub fn bind_and_map( register_state: &mut RegisterState<RegisterStorageEnum>, exception_report: &mut zx_exception_report_t, ) -> Result<Self, Status>

Allocates a VMO for the restricted state and maps it into the Starnix kernel.

The VMO is created using zx_restricted_bind_state and then mapped into the kernel’s address space. This allows Starnix to inspect and modify the restricted state (registers) of the task.